!              #include Zcode.h is needed
        integer nmax, maxDecay
        parameter  ( nmax = 50000,  maxDecay = 8 )
        integer Jdecay(klast)

        common /ctestcol/ Jdecay


